Okta
-----

.. code-block:: python

    SOCIALACCOUNT_PROVIDERS = {
        'okta': {
            'OKTA_BASE_URL': 'example.okta.com',
            'OAUTH_PKCE_ENABLED': True,
        }
    }

Okta OIDC
    https://developer.okta.com/docs/reference/api/oidc/
